import { useState } from "react";
import { useForm } from "@inertiajs/react";
import { DragDropContext, Droppable, Draggable } from "react-beautiful-dnd";

export default function Kanban({ funnel }) {
    const { post } = useForm();

    const [data, setData] = useState(funnel);

    const handleDragEnd = (result) => {
        if (!result.destination) return;

        const { source, destination, draggableId } = result;
        const leadId = draggableId;
        const newStageId = destination.droppableId;

        post("/leads/update-position", {
            lead_id: leadId,
            new_stage_id: newStageId,
        });

        // Atualiza o estado localmente para melhor UX
        const newData = [...data];
        const sourceStage = newData.find(stage => stage.id == source.droppableId);
        const destStage = newData.find(stage => stage.id == destination.droppableId);
        const lead = sourceStage.leads.find(lead => lead.id == leadId);

        sourceStage.leads = sourceStage.leads.filter(lead => lead.id != leadId);
        destStage.leads.push(lead);

        setData(newData);
    };

    return (
        <>
            <h1>{funnel?.name}</h1>

            <DragDropContext onDragEnd={handleDragEnd}>
                <div className="flex gap-4  overflow-x-auto p-4 scrollbar-hide">
                    {data.stages.map((stage) => (
                        <Droppable key={stage.id} droppableId={stage.id}>
                            {(provided) => (
                                <div ref={provided.innerRef}  {...provided.droppableProps} className="w-72 bg-gray-200 p-4 rounded-lg">
                                    <h2 className="font-bold text-lg">{stage.name}</h2>
                                    {/* {stage.leads.map((lead, index) => (
                                        <Draggable key={lead.id} draggableId={String(lead.id)} index={index}>
                                            {(provided) => (
                                                <div
                                                    ref={provided.innerRef}
                                                    {...provided.draggableProps}
                                                    {...provided.dragHandleProps}
                                                    className="mt-2 p-2 bg-white rounded shadow"
                                                >
                                                    {lead.name}
                                                </div>
                                            )}
                                        </Draggable>
                                    ))} */}
                                    {provided.placeholder}
                                </div>
                            )}
                        </Droppable>
                    ))}
                </div>
            </DragDropContext>
        </>
    );
};
